# Probnode

[![Downloads](https://pepy.tech/badge/probnode)](https://pepy.tech/project/probnode)
[![Downloads](https://pepy.tech/badge/probnode/month)](https://pepy.tech/project/probnode)
[![GitHub stars](https://img.shields.io/github/stars/medasmarathon/Probnode)](https://github.com/medasmarathon/Probnode/stargazers)

## Description

Probability expression library

## Features

- Basic events and probability concepts modeling
- Calculation on a chain of probability expressions
- Contract and/or expand probability expressions chain, using probability mathematical characteristics

## Installation

```python
    pip install probnode
```

## Documentation

### [Project Wiki](https://github.com/medasmarathon/Probnode/wiki)

<br>

<a href="https://www.buymeacoffee.com/dangduc"><img height="40" src="https://img.buymeacoffee.com/button-api/?text=Support&emoji=&slug=dangduc&button_colour=1db487&font_colour=000000&font_family=Comic&outline_colour=000000&coffee_colour=FFDD00" /></a>
